import MHeader from '@/components/m-header';
import MSticky from '@/components/m-sticky';
import { defineComponent, onMounted, reactive, ref } from 'vue';
import styles from './index.module.less';
import { useRoute, useRouter } from 'vue-router';
import request from '@/helpers/request';
import Moveable from 'moveable';
import { useEventListener, useWindowScroll } from '@vueuse/core';
import iconExamQuestion from './images/icon-exam-question.png';
import MEmpty from '@/components/m-empty';
import { showToast } from 'vant';

export default defineComponent({
  name: 'unit-detail',
  setup() {
    const router = useRouter();
    const route = useRoute();

    const forms = reactive({
      detailId: route.query.detailId,
      loading: false,
      background: 'transparent',
      color: '#fff',
      dataInfo: {} as any
    });

    const getList = async () => {
      forms.loading = true;
      try {
        const { data } = await request.get(
          '/edu-app/lessonCoursewareKnowledgeDetail/detail/' + forms.detailId
        );
        forms.dataInfo = data;
      } catch {
        //
      }
      forms.loading = false;
    };

    const onGotoModel = async () => {
      try {
        const { data } = await request.get(
          '/edu-app/studentUnitExamination/checkKnowledgePointIds',
          {
            params: {
              knowledgePointIds: forms.dataInfo.knowledgePointIds
            }
          }
        );
        if (data) {
          router.push({
            path: '/practice-mode',
            query: { knowledgePointIds: forms.dataInfo.knowledgePointIds }
          });
        } else {
          setTimeout(() => {
            showToast('暂无题目');
          }, 100);
          return;
        }
      } catch {
        //
      }
    };

    const __initMove = () => {
      const moveable = new Moveable(document.body, {
        target: document.querySelector('#iconExamQuestion') as any,
        // If the container is null, the position is fixed. (default: parentElement(document.body))
        container: document.body,
        draggable: true,
        resizable: false,
        scalable: false,
        rotatable: false,
        warpable: false,
        // Enabling pinchable lets you use events that
        // can be used in draggable, resizable, scalable, and rotateable.
        pinchable: false, // ["resizable", "scalable", "rotatable"]
        origin: false,
        keepRatio: false,
        // Resize, Scale Events at edges.
        edge: false,
        throttleDrag: 0,
        throttleResize: 0,
        throttleScale: 0,
        throttleRotate: 0
      });

      moveable
        .on('dragStart', ({ target, clientX, clientY }) => {
          // console.log('onDragStart', target);
        })
        .on(
          'drag',
          ({
            target,
            transform,
            left,
            top,
            right,
            bottom,
            beforeDelta,
            beforeDist,
            delta,
            dist,
            clientX,
            clientY
          }) => {
            // console.log({ left, top, right, bottom });
            // console.log({ clientX, clientY });
            // console.log(target.clientWidth, target.clientHeight);
            // console.log(document.body.clientWidth, document.body.clientHeight);
            const docWidth = document.body.clientWidth;
            const docHeight = document.body.clientHeight;
            if (left <= 0) {
              target!.style.left = `${0}px`;
            } else if (docWidth - target.clientWidth / 1.6 <= clientX) {
              target!.style.left = `${docWidth - target.clientWidth}px`;
            } else {
              target!.style.left = `${left}px`;
            }
            if (top <= 0) {
              target!.style.top = `${0}px`;
            } else if (docHeight - target.clientHeight / 1.6 <= clientY) {
              target!.style.top = `${docHeight - target.clientHeight}px`;
            } else {
              target!.style.top = `${top}px`;
            }

            // console.log("onDrag translate", dist);
            // target!.style.transform = transform;
          }
        )
        .on('dragEnd', ({ target, isDrag, clientX, clientY }) => {
          // console.log('onDragEnd', target, isDrag);
        });
    };

    onMounted(() => {
      useEventListener(document, 'scroll', () => {
        const { y } = useWindowScroll();
        if (y.value > 52) {
          forms.background = '#fff';
          forms.color = '#323333';
        } else {
          forms.background = 'transparent';
          forms.color = '#fff';
        }
      });

      __initMove();

      getList();
    });
    return () => (
      <div class={styles.knowledgeLibrary}>
        <MSticky position="top">
          <MHeader
            border={false}
            background={forms.background}
            color={forms.color}>
            {/* {{
              right: () => (
                <div
                  class={styles.wroingBtn}
                  onClick={() => router.push('/wroing-book')}>
                  <i class={styles.iconWroing}></i>错题本
                </div>
              )
            }} */}
          </MHeader>
        </MSticky>

        <div class={[styles.containerSection, styles.woringSection]}>
          {forms.dataInfo.desc && (
            <div
              class={styles.woringContent}
              v-html={forms.dataInfo.desc}></div>
          )}
          {!forms.dataInfo.desc && !forms.loading && (
            <div class={styles.woringContent}>
              <MEmpty description="暂无内容" style={{ paddingTop: '40px' }} />
            </div>
          )}
        </div>

        <img
          id="iconExamQuestion"
          src={iconExamQuestion}
          class={styles.iconExamQuestion}
          onClick={onGotoModel}
        />
      </div>
    );
  }
});
